# Welcome to geoca


[![image](https://img.shields.io/pypi/v/geoca.svg)](https://pypi.python.org/pypi/geoca)


**A Python module for CA models based on geo-raster data**


-   Free software: MIT License
-   Documentation: <https://Haorui-Jiang.github.io/geoca>
    

## Features

-   TODO
